# cirq-qrack

This repository contains a Qrack plugin for Cirq, providing the Qrack QasmSimulator. The underlying Qrack simulator is a high-performance, GPU-accelerated, noiseless simulator, by design.

This plugin is based on and adapted from work by the **qulacs team**, the **IBM Qiskit Team**, and **QCGPU's creator, Adam Kelly**. Quantum volume benchmarks come from the qulacs plugin for Cirq at [https://github.com/qulacs/cirq-qulacs](https://github.com/qulacs/cirq-qulacs). Attribution is also noted in content files, where appropriate. Original contributions and adaptations were made by Daniel Strano of the Qrack/VM6502Q Team.
